==> mongrel2_1.11.0.orig.tar.xz: mongrel2-1.11.0/README.md <==
Mongrel2: The Language Agnostic Web Server
==========================================

Mongrel2 is an application, language, and network architecture agnostic web
server that focuses on web applications using modern browser technologies.

Features
--------

* Language Agnostic with a simple backend protocol supporting 17 languages and
  platforms all written by Mongrel2 fans.
* Modern Browser Friendly designed to handle HTTP, Flash XMLSockets, or
  WebSockets, Long Polling on the same socket transparently.
* ZeroMQ Enabled as well as HTTP proxy support so it works with what you have
  already while giving you new super powers.
* Network Architecture Agnostic so you can carve your operations up any way that
  reduces costs.
* N:M Messaging Patterns means you can have any N handlers answer to any M
  browsers arbitrarily, but still easy to do plain request/response.
* Automation Loving Configs that are easily accessible via any programming
  language with a Model-View-Controller design.
* Modern Internal Design using the Mongrel 1 HTTP parser powering many big
  companies with a proven security track record, event based I/O, fast
  coroutines to handle that I/O, and smart reasonable defaults with zero
  configuration needed usually.
* Documented, Documented, Documented. We document everything in a well written
  manual that shows you how to use every feature.
* BSD Licensed and all with a BSD 3-clause license.
* Tir -- An official framework written in Lua that shows how to use Mongrel2 to
  create other frameworks for PHP, Python, etc.

Download
--------

mongrel2 is now v1.11.0 as of *Thu Dec 31 2015*:

* [mongrel2-v1.11.0.tar.bz2](https://github.com/mongrel2/mongrel2/releases/v1.11.0/download/mongrel2-v1.11.0.tar.bz2)

Documentation
-------------

Go to [http://mongrel2.org](http://mongrel2.org) for more information.

==> mongrel2_1.12.2.orig.tar.xz: mongrel2-1.12.2/README.md <==
Mongrel2: The Language Agnostic Web Server
==========================================

Mongrel2 is an application, language, and network architecture agnostic web
server that focuses on web applications using modern browser technologies.

Features
--------

* Language Agnostic with a simple backend protocol supporting 17 languages and
  platforms all written by Mongrel2 fans.
* Modern Browser Friendly designed to handle HTTP, Flash XMLSockets, or
  WebSockets, Long Polling on the same socket transparently.
* ZeroMQ Enabled as well as HTTP proxy support so it works with what you have
  already while giving you new super powers.
* Network Architecture Agnostic so you can carve your operations up any way that
  reduces costs.
* N:M Messaging Patterns means you can have any N handlers answer to any M
  browsers arbitrarily, but still easy to do plain request/response.
* Automation Loving Configs that are easily accessible via any programming
  language with a Model-View-Controller design.
* Modern Internal Design using the Mongrel 1 HTTP parser powering many big
  companies with a proven security track record, event based I/O, fast
  coroutines to handle that I/O, and smart reasonable defaults with zero
  configuration needed usually.
* Documented, Documented, Documented. We document everything in a well written
  manual that shows you how to use every feature.
* BSD Licensed and all with a BSD 3-clause license.
* Tir -- An official framework written in Lua that shows how to use Mongrel2 to
  create other frameworks for PHP, Python, etc.

Download
--------

mongrel2 is now v1.12.2 as of *Fri Jun 14 2019*:

* [mongrel2-v1.12.2.tar.bz2](https://github.com/mongrel2/mongrel2/releases/v1.12.2/download/mongrel2-v1.12.2.tar.bz2)

Documentation
-------------

Go to [http://mongrel2.org](http://mongrel2.org) for more information.
